==> xlniuxdata-vipgame-1.0.33-20151112.053636-31-sources.jar: com/xunlei/niux/data/vipgame/bo/gift/GiftRecordBo.java <==
package com.xunlei.niux.data.vipgame.bo.gift;

import com.xunlei.niux.data.vipgame.dto.ActivityNGiftNGiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;

import java.util.List;
import java.util.Set;

/**
 * Created by jamesjxin on 14-4-17.
 */
public interface GiftRecordBo {

    public List<GiftRecordDTO> getUnReleaseProductGiftRecord();
    public List<ProductDTO> getBonusProductChargeList(int max) ;
    List<?> getJiFenShopGiftRecord(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize);
    public List<ProductDTO> getTimeLimitBonusProductChargeList(final int max);
    List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSete, int pageNo, int pageSize);

    int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet);

    int coutJiFenShopGiftRecord(String userId,  Set<String> giftTypeParamSet);

    /**
     * get all user giftrecord by actNo
     * @param userId
     * @param actNo
     * @return
     */
    List<ActivityNGiftNGiftRecordDTO> getUserGiftRecordsByActNo(String userId,String actNo);
    
    
    int countGiftRecordInOneDay(String userId, String date);

    int countGiftRecord(String userId, String startTime, String endTime);

    int countGiftRecord(String userId, String giftType, String startTime, String endTime);

    List<ProductDTO> getBonusProductChargeList(int listNum,boolean isTimeLimit, boolean isEntityGift);
}

==> xlniuxdata-vipgame-1.0.43-20160105.114259-4-sources.jar: com/xunlei/niux/data/vipgame/bo/gift/GiftRecordBo.java <==
package com.xunlei.niux.data.vipgame.bo.gift;

import com.xunlei.niux.data.vipgame.dto.ActivityNGiftNGiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;

import java.util.List;
import java.util.Set;

/**
 * Created by jamesjxin on 14-4-17.
 */
public interface GiftRecordBo {

    public List<GiftRecordDTO> getUnReleaseProductGiftRecord();
    public List<ProductDTO> getBonusProductChargeList(int max) ;
    List<?> getJiFenShopGiftRecord(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize);
    public List<ProductDTO> getTimeLimitBonusProductChargeList(final int max);
    List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSete, int pageNo, int pageSize);

    int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet);

    int coutJiFenShopGiftRecord(String userId,  Set<String> giftTypeParamSet);

    /**
     * get all user giftrecord by actNo
     * @param userId
     * @param actNo
     * @return
     */
    List<ActivityNGiftNGiftRecordDTO> getUserGiftRecordsByActNo(String userId,String actNo);
    
    
    int countGiftRecordInOneDay(String userId, String date);

    int countGiftRecord(String userId, String startTime, String endTime);

    int countGiftRecord(String userId, String giftType, String startTime, String endTime);

    List<ProductDTO> getBonusProductChargeList(int listNum,boolean isTimeLimit, boolean isEntityGift);
    List<ProductDTO> getBonusProductChargeList(int listNum,boolean isTimeLimit, boolean isEntityGift,boolean isBox);
    
    List<ProductDTO> getBoxBonusProductChargeList(int listNum,boolean isTimeLimit, boolean isEntityGift);
    
  //获取相对于当天相差addDays天的兑换商品
    List<ProductDTO> getDayBoxProduct(boolean isTimeLimit, boolean isEntityGift, int listNum,int giftId);
}
